Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: chrome/renderer/autofill/autofill_agent.h

Issue 10024059: DataList UI (Chromium part) (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fixed Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/autofill/autofill_agent.h
diff --git a/chrome/renderer/autofill/autofill_agent.h b/chrome/renderer/autofill/autofill_agent.h
index 843ee6cdc44a9a0619e4ef3a5e87e1bde15dd10c..fda9de3dcc1cc34327ff3b0fb1bcbc4237ce1c20 100644
--- a/chrome/renderer/autofill/autofill_agent.h
+++ b/chrome/renderer/autofill/autofill_agent.h
@@ -76,12 +76,12 @@ class AutofillAgent : public content::RenderViewObserver,
virtual void didAcceptAutofillSuggestion(const WebKit::WebNode& node,
const WebKit::WebString& value,
const WebKit::WebString& label,
- int unique_id,
+ int item_id,
unsigned index) OVERRIDE;
virtual void didSelectAutofillSuggestion(const WebKit::WebNode& node,
const WebKit::WebString& value,
const WebKit::WebString& label,
- int unique_id) OVERRIDE;
+ int item_id) OVERRIDE;
virtual void didClearAutofillSelection(const WebKit::WebNode& node) OVERRIDE;
virtual void removeAutocompleteSuggestion(
const WebKit::WebString& name,
@@ -137,8 +137,14 @@ class AutofillAgent : public content::RenderViewObserver,
void QueryAutofillSuggestions(const WebKit::WebInputElement& element,
bool display_warning_if_disabled);
+ void CombineDataListEntriesAndShow(const WebKit::WebInputElement& element,
+ const std::vector<string16>& values,
+ const std::vector<string16>& labels,
+ const std::vector<string16>& icons,
+ const std::vector<int>& item_ids);
Ilya Sherman 2012/04/11 19:09:58 nit: Align with the opening paren
keishi 2012/04/12 14:07:11 Done.
+
// Queries the AutofillManager for form data for the form containing |node|.
// |value| is the current text in the field, and |unique_id| is the selected
Ilya Sherman 2012/04/11 19:09:58 nit: unique_id
keishi 2012/04/12 14:07:11 Done.
// profile's unique ID. |action| specifies whether to Fill or Preview the
// values returned from the AutofillManager.
void FillAutofillFormData(const WebKit::WebNode& node,
@@ -164,7 +170,7 @@ class AutofillAgent : public content::RenderViewObserver,
int autofill_query_id_;
// The element corresponding to the last request sent for form field Autofill.
- WebKit::WebInputElement autofill_query_element_;
+ WebKit::WebInputElement element_;
// The action to take when receiving Autofill data from the AutofillManager.
AutofillAction autofill_action_;
@@ -175,12 +181,6 @@ class AutofillAgent : public content::RenderViewObserver,
// Was the query node autofilled prior to previewing the form?
bool was_query_node_autofilled_;
- // The menu index of the "Clear" menu item.
- int suggestions_clear_index_;
-
- // The menu index of the "Autofill options..." menu item.
- int suggestions_options_index_;
-
// Have we already shown Autofill suggestions for the field the user is
// currently editing? Used to keep track of state for metrics logging.
bool has_shown_autofill_popup_for_current_edit_;
@@ -137,8 +137,14 @@ class AutofillAgent : public content::RenderViewObserver,
// Queries the AutofillManager for form data for the form containing |node|.
- // |value| is the current text in the field, and |unique_id| is the selected
+ // |value| is the current text in the field, and |item_id| is the selected
Ilya Sherman 2012/04/11 19:09:58 nit: unique_id
keishi 2012/04/12 14:07:11 Done.

Powered by Google App Engine
This is Rietveld 408576698